# -*- coding: utf-8 -*-

# Resource object code
#
# Created: Tue Feb 25 09:19:19 2014
#      by: The Resource Compiler for PySide (Qt v4.8.4)
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore

qt_resource_data = b"\x00\x00R//*\x0a * The MIT License (MIT)\x0a *\x0a * Copyright (c) <2013-2014> <Colin Duquesnoy>\x0a *\x0a * Permission is hereby granted, free of charge, to any person obtaining a copy\x0a * of this software and associated documentation files (the \x22Software\x22), to deal\x0a * in the Software without restriction, including without limitation the rights\x0a * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\x0a * copies of the Software, and to permit persons to whom the Software is\x0a * furnished to do so, subject to the following conditions:\x0a\x0a * The above copyright notice and this permission notice shall be included in\x0a * all copies or substantial portions of the Software.\x0a\x0a * THE SOFTWARE IS PROVIDED \x22AS IS\x22, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\x0a * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\x0a * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\x0a * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\x0a * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\x0a * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\x0a * THE SOFTWARE.\x0a */\x0a\x0aQProgressBar:horizontal {\x0a    border: 1px solid #3A3939;\x0a    text-align: center;\x0a    padding: 1px;\x0a    background: #201F1F;\x0a}\x0aQProgressBar::chunk:horizontal {\x0a    background-color: qlineargradient(spread:reflect, x1:1, y1:0.545, x2:1, y2:0, stop:0 rgba(28, 66, 111, 255), stop:1 rgba(37, 87, 146, 255));\x0a}\x0a\x0aQToolTip\x0a{\x0a    border: 1px solid #3A3939;\x0a    background-color: rgb(90, 102, 117);;\x0a    color: white;\x0a    padding: 1px;\x0a    opacity: 200;\x0a}\x0a\x0aQWidget\x0a{\x0a    color: silver;\x0a    background-color: #302F2F;\x0a    selection-background-color:#78879b;\x0a    selection-color: black;\x0a    background-clip: border;\x0a    border-image: none;\x0a    outline: 0;\x0a}\x0a\x0aQWidget:item:hover\x0a{\x0a    background-color: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1,\x0a    stop: 0 #78879b, stop: 1 #78879b);\x0a    color: black;\x0a}\x0a\x0aQWidget:item:selected\x0a{\x0a    background-color: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1,\x0a    stop: 0 #78879b, stop: 1 #78879b);\x0a}\x0a\x0aQMenuBar\x0a{\x0a    background-color: #302F2F;\x0a    color: silver;\x0a}\x0a\x0aQMenuBar::item\x0a{\x0a    background: transparent;\x0a}\x0a\x0aQMenuBar::item:selected\x0a{\x0a    background: transparent;\x0a    border: 1px solid #3A3939;\x0a}\x0a\x0aQMenuBar::item:pressed\x0a{\x0a    border: 1px solid #3A3939;\x0a    background-color: #78879b;\x0a    color: black;\x0a    margin-bottom:-1px;\x0a    padding-bottom:1px;\x0a}\x0a\x0aQMenu\x0a{\x0a    border: 1px solid #3A3939;\x0a    color: silver;\x0a    margin: 2px;\x0a}\x0a\x0aQMenu::icon\x0a{\x0a    margin: 5px;\x0a}\x0a\x0aQMenu::item\x0a{\x0a    padding: 5px 30px 5px 30px;\x0a    margin-left: 5px;\x0a    border: 1px solid transparent; /* reserve space for selection border */\x0a}\x0a\x0aQMenu::item:selected\x0a{\x0a    color: black;\x0a}\x0a\x0aQWidget:disabled\x0a{\x0a    color: #404040;\x0a    background-color: #302F2F;\x0a}\x0a\x0aQAbstractItemView\x0a{\x0a    alternate-background-color: #3A3939;\x0a    color: silver;\x0a    border: 1px solid 3A3939;\x0a    border-radius: 3px;\x0a    padding: 1px;\x0a}\x0a\x0aQWidget:focus, QMenuBar:focus\x0a{\x0a    border: 1px solid rgba(48, 86, 111);\x0a}\x0a\x0aQTabWidget:focus, QCheckBox:focus, QRadioButton:focus\x0a{\x0a    border: none;\x0a}\x0a\x0aQLineEdit\x0a{\x0a    background-color: #201F1F;\x0a    padding: 2px;\x0a    border-style: solid;\x0a    border: 1px solid #3A3939;\x0a    border-radius: 3px;\x0a    color: silver;\x0a}\x0a\x0aQGroupBox {\x0a    border:1px solid #3A3939;\x0a    border-radius: 7px;\x0a    margin-top: 2ex;\x0a}\x0a\x0aQGroupBox::title {\x0a    subcontrol-origin: margin;\x0a    subcontrol-position: top center;\x0a    padding-left: 10px;\x0a    padding-right: 10px;\x0a}\x0a\x0aQAbstractScrollArea\x0a{\x0a    border-radius: 3px;\x0a    border: 1px solid #3A3939;\x0a}\x0a\x0aQScrollBar:horizontal\x0a{\x0a    height: 15px;\x0a    margin: 0px 11px 0px 11px;\x0a    border: 1px solid #3A3939;\x0a    border-radius: 6px;\x0a    background-color: QLinearGradient( x1: 0, y1: 1, x2: 0, y2: 0,\x0a    stop: 0 #302F2F, stop: 1 #484846);\x0a}\x0a\x0aQScrollBar::handle:horizontal\x0a{\x0a    background-color: QLinearGradient( x1: 0, y1: 1, x2: 0, y2: 0,\x0a    stop: 0 #605F5F, stop: 1 #787876);\x0a    min-width: 5px;\x0a    border-radius: 5px;\x0a}\x0a\x0aQScrollBar::sub-line:horizontal\x0a{\x0a    border-image: url(:/qss_icons/rc/right_arrow_disabled.png);\x0a    width: 10px;\x0a    height: 10px;\x0a    subcontrol-position: right;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::add-line:horizontal\x0a{\x0a    border-image: url(:/qss_icons/rc/left_arrow_disabled.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: left;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::sub-line:horizontal:hover,QScrollBar::sub-line:horizontal:on\x0a{\x0a    border-image: url(:/qss_icons/rc/right_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: right;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0a\x0aQScrollBar::add-line:horizontal:hover, QScrollBar::add-line:horizontal:on\x0a{\x0a    border-image: url(:/qss_icons/rc/left_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: left;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal\x0a{\x0a    background: none;\x0a}\x0a\x0a\x0aQScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal\x0a{\x0a    background: none;\x0a}\x0a\x0aQScrollBar:vertical\x0a{\x0a    background-color: QLinearGradient( x1: 1, y1: 0, x2: 0, y2: 0,\x0a    stop: 0 #302F2F, stop: 1 #484846);\x0a    width: 15px;\x0a    margin: 11px 0 11px 0;\x0a    border: 1px solid #3A3939;\x0a    border-radius: 6px;\x0a}\x0a\x0aQScrollBar::handle:vertical\x0a{\x0a    background-color: QLinearGradient( x1: 1, y1: 0, x2: 0, y2: 0,\x0a    stop: 0 #605F5F, stop: 1 #787876);\x0a    min-height: 5px;\x0a    border-radius: 5px;\x0a}\x0a\x0aQScrollBar::sub-line:vertical\x0a{\x0a    border-image: url(:/qss_icons/rc/up_arrow_disabled.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: top;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::add-line:vertical\x0a{\x0a\x0a    border-image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: bottom;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::sub-line:vertical:hover,QScrollBar::sub-line:vertical:on\x0a{\x0a\x0a    border-image: url(:/qss_icons/rc/up_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: top;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0a\x0aQScrollBar::add-line:vertical:hover, QScrollBar::add-line:vertical:on\x0a{\x0a    border-image: url(:/qss_icons/rc/down_arrow.png);\x0a    height: 10px;\x0a    width: 10px;\x0a    subcontrol-position: bottom;\x0a    subcontrol-origin: margin;\x0a}\x0a\x0aQScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical\x0a{\x0a    background: none;\x0a}\x0a\x0a\x0aQScrollBar::add-page:vertical, QScrollBar::sub-page:vertical\x0a{\x0a    background: none;\x0a}\x0a\x0aQTextEdit\x0a{\x0a    background-color: #201F1F;\x0a    color: silver;\x0a    border: 1px solid #3A3939;\x0a}\x0a\x0aQPlainTextEdit\x0a{\x0a    background-color: #201F1F;;\x0a    color: silver;\x0a    border-radius: 3px;\x0a    border: 1px solid #3A3939;\x0a}\x0a\x0aQHeaderView::section\x0a{\x0a    background-color: #3A3939;\x0a    color: silver;\x0a    padding-left: 4px;\x0a    border: 1px solid #6c6c6c;\x0a}\x0a\x0aQCheckBox:disabled\x0a{\x0a    color: #404040;\x0a}\x0a\x0aQSizeGrip {\x0a    image: url(:/qss_icons/rc/sizegrip.png);\x0a    width: 12px;\x0a    height: 12px;\x0a}\x0a\x0a\x0aQMainWindow::separator\x0a{\x0a    background-color: #302F2F;\x0a    color: white;\x0a    padding-left: 4px;\x0a    spacing: 2px;\x0a    border: 1px dashed #3A3939;\x0a}\x0a\x0aQMainWindow::separator:hover\x0a{\x0a\x0a    background-color: QLinearGradient(x1:0, y1:0, x2:0, y2:1, stop:0 #58677b,\x0a      stop:0.5 #78879b stop:1 #58677b);\x0a    color: white;\x0a    padding-left: 4px;\x0a    border: 1px solid #3A3939;\x0a    spacing: 2px;\x0a}\x0a\x0a\x0aQMenu::separator\x0a{\x0a    height: 1px;\x0a    background-color: #3A3939;\x0a    color: white;\x0a    padding-left: 4px;\x0a    margin-left: 10px;\x0a    margin-right: 5px;\x0a}\x0a\x0a\x0a\x0aQRadioButton::indicator:checked, QRadioButton::indicator:unchecked{\x0a    color: #b1b1b1;\x0a    background-color: #302F2F;\x0a    border: 1px solid silver;\x0a    border-radius: 5px;\x0a}\x0a\x0a\x0a\x0aQRadioButton::indicator:checked\x0a{\x0a    background-color: qradialgradient(\x0a    cx: 0.5, cy: 0.5,\x0a    fx: 0.5, fy: 0.5,\x0a    radius: 1.0,\x0a    stop: 0.25 #78879b,\x0a    stop: 0.3 #302F2F\x0a    );\x0a}\x0a\x0aQCheckBox, QRadioButton\x0a{\x0a    padding: 3px;\x0a    outline: none;\x0a}\x0a\x0aQCheckBox::indicator{\x0a    color: #b1b1b1;\x0a    background-color: #302F2F;\x0a    border: 1px solid silver;\x0a    width: 9px;\x0a    height: 9px;\x0a}\x0a\x0aQRadioButton::indicator\x0a{\x0a    border-radius: 7px;\x0a    width: 9px;\x0a    height: 9px;\x0a}\x0a\x0aQCheckBox::indicator:pressed\x0a{\x0a    border: 1px solid #78879b;\x0a}\x0a\x0aQRadioButton::indicator:hover, QCheckBox::indicator:hover\x0a{\x0a    border: 1px solid #78879b;\x0a}\x0a\x0aQCheckBox::indicator:checked\x0a{\x0a    image:url(:/qss_icons/rc/checkbox.png);\x0a}\x0a\x0aQCheckBox::indicator:disabled, QRadioButton::indicator:disabled\x0a{\x0a    border: 1px solid #444;\x0a}\x0a\x0aQFrame\x0a{\x0a    border-radius: 3px;\x0a}\x0a\x0aQStackedWidget\x0a{\x0a    border: none;\x0a}\x0a\x0aQToolBar {\x0a    border: 1px solid #393838;\x0a    background: 1px solid #302F2F;\x0a    font-weight: bold;\x0a}\x0a\x0aQToolBar::handle:horizontal {\x0a    image: url(:/qss_icons/rc/Hmovetoolbar.png);\x0a}\x0aQToolBar::handle:vertical {\x0a    image: url(:/qss_icons/rc/Vmovetoolbar.png);\x0a}\x0aQToolBar::separator:horizontal {\x0a    image: url(:/qss_icons/rc/Hsepartoolbar.png);\x0a}\x0aQToolBar::separator:vertical {\x0a    image: url(:/qss_icons/rc/Vsepartoolbars.png);\x0a}\x0a\x0aQPushButton\x0a{\x0a    color: silver;\x0a    background-color: QLinearGradient( x1: 0, y1: 1, x2: 0, y2: 0,\x0a    stop: 0 #302F2F, stop: 1 #484846);\x0a    border-width: 1px;\x0a    border-color: #4A4949;\x0a    border-style: solid;\x0a    padding-top: 5px;\x0a    padding-bottom: 5px;\x0a    padding-left: 5px;\x0a    padding-right: 5px;\x0a    border-radius: 5px;\x0a    outline: none;\x0a}\x0a\x0aQPushButton:disabled\x0a{\x0a    background-color: #302F2F;\x0a    border-width: 1px;\x0a    border-color: #3A3939;\x0a    border-style: solid;\x0a    padding-top: 5px;\x0a    padding-bottom: 5px;\x0a    padding-left: 10px;\x0a    padding-right: 10px;\x0a    /*border-radius: 3px;*/\x0a    color: #454545;\x0a}\x0a\x0aQComboBox\x0a{\x0a    selection-background-color: #78879b;\x0a    background-color: #201F1F;\x0a    border-style: solid;\x0a    border: 1px solid #3A3939;\x0a    border-radius: 3px;\x0a    padding: 2px;\x0a}\x0a\x0aQComboBox:hover,QPushButton:hover,QAbstractSpinBox:hover,QLineEdit:hover,QTextEdit:hover,QPlainTextEdit:hover,QAbstractView:hover,QTreeView:hover\x0a{\x0a    border: 1px solid #78879b;\x0a    color: silver;\x0a}\x0a\x0aQComboBox:on\x0a{\x0a    background-color: #626873;\x0a    padding-top: 3px;\x0a    padding-left: 4px;\x0a    selection-background-color: #4a4a4a;\x0a}\x0a\x0aQComboBox QAbstractItemView\x0a{\x0a    background-color: #201F1F;\x0a    border-radius: 3px;\x0a    border: 1px solid #3A3939;\x0a    selection-background-color: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1,\x0a      stop: 0 #78879b, stop: 1 #78879b);\x0a}\x0a\x0aQComboBox::drop-down\x0a{\x0a    subcontrol-origin: padding;\x0a    subcontrol-position: top right;\x0a    width: 15px;\x0a\x0a    border-left-width: 0px;\x0a    border-left-color: darkgray;\x0a    border-left-style: solid;\x0a    border-top-right-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQComboBox::down-arrow\x0a{\x0a    image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a}\x0a\x0aQComboBox::down-arrow:on, QComboBox::down-arrow:hover,\x0aQComboBox::down-arrow:focus\x0a{\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0aQPushButton:pressed\x0a{\x0a    background-color: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1,\x0a    stop: 0 #302F2F, stop: 1 #484846);\x0a}\x0a\x0aQAbstractSpinBox {\x0a    padding-top: 2px;\x0a    padding-bottom: 2px;\x0a    border: 1px solid #3A3939;\x0a    background-color: #201F1F;\x0a    color: silver;\x0a    border-radius: 3px;\x0a}\x0a\x0aQAbstractSpinBox:up-button\x0a{\x0a    background-color: transparent;\x0a    subcontrol-origin: border;\x0a    subcontrol-position: center right;\x0a}\x0a\x0aQAbstractSpinBox:down-button\x0a{\x0a    background-color: transparent;\x0a    subcontrol-origin: border;\x0a    subcontrol-position: center left;\x0a}\x0a\x0aQAbstractSpinBox::up-arrow,QAbstractSpinBox::up-arrow:disabled,QAbstractSpinBox::up-arrow:off {\x0a    image: url(:/qss_icons/rc/up_arrow_disabled.png);\x0a    width: 10px;\x0a    height: 10px;\x0a}\x0aQAbstractSpinBox::up-arrow:hover\x0a{\x0a    image: url(:/qss_icons/rc/up_arrow.png);\x0a}\x0a\x0a\x0aQAbstractSpinBox::down-arrow,QAbstractSpinBox::down-arrow:disabled,QAbstractSpinBox::down-arrow:off\x0a{\x0a    image: url(:/qss_icons/rc/down_arrow_disabled.png);\x0a    width: 10px;\x0a    height: 10px;\x0a}\x0aQAbstractSpinBox::down-arrow:hover\x0a{\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0a\x0aQLabel\x0a{\x0a    border: 0px solid black;\x0a}\x0a\x0a\x0aQTabWidget::pane {\x0a    border: 1px solid #3A3939;\x0a}\x0a\x0aQTabBar\x0a{\x0a    qproperty-drawBase: 0;\x0a    padding-right: 15px;\x0a}\x0a\x0aQTabBar:focus\x0a{\x0a    border: 0px transparent black;\x0a}\x0a\x0aQTabBar::close-button  {\x0a    image: url(:/qss_icons/rc/close.png);\x0a    background: transparent;\x0a    icon-size: 10px;\x0a    padding: 5px;\x0a}\x0a\x0aQTabBar::close-button:hover\x0a{\x0a    background: rgba(255, 255, 255, 20);\x0a    border-radius: 3px;\x0a}\x0a\x0aQTabBar::close-button:pressed {\x0a    padding: 5px 4px 4px 5px;\x0a}\x0a\x0aQTabBar::tab:!selected:hover\x0a{\x0a    color:white;\x0a}\x0a\x0aQTabBar::tab:selected:hover\x0a{\x0a    color: white;\x0a}\x0a\x0a/* TOP - BOTTOM TABS */\x0aQTabBar::tab:top {\x0a    color: #b1b1b1;\x0a    border: 1px solid #3A3939;\x0a    background-color: QLinearGradient(x1:0, y1:0, x2:0, y2:1,\x0a      stop:1 #302F2F, stop:0 #5A5959);\x0a    padding-left: 5px;\x0a    padding-right: 5px;\x0a    padding-top: 3px;\x0a    padding-bottom: 2px;\x0a    margin-right: -1px;\x0a\x0a    border-top-left-radius: 3px;\x0a    border-top-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:bottom {\x0a    color: #b1b1b1;\x0a    border: 1px solid #3A3939;\x0a    background-color: QLinearGradient(x1:0, y1:0, x2:0, y2:1,\x0a      stop:1 #302F2F, stop:0 #5A5959);\x0a    padding-left: 5px;\x0a    padding-right: 5px;\x0a    padding-top: 3px;\x0a    padding-bottom: 2px;\x0a    margin-right: -1px;\x0a\x0a    border-bottom-left-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:top:last, QTabBar::tab:bottom:last\x0a{\x0a    margin-right: 0;\x0a}\x0a\x0aQTabBar::tab:top:first:!selected, QTabBar::tab:bottom:first:!selected\x0a{\x0a    margin-left: 0px;\x0a}\x0a\x0aQTabBar::tab:top:!selected\x0a{\x0a    color: #b1b1b1;\x0a    margin-top: 3px;\x0a}\x0a\x0aQTabBar::tab:top:selected\x0a{\x0a    margin-bottom: 0px;\x0a}\x0a\x0aQTabBar::tab:bottom:!selected\x0a{\x0a    color: #b1b1b1;\x0a    margin-bottom: 3px;\x0a}\x0a\x0aQTabBar::tab:bottom:selected\x0a{\x0a    color: #D1D1D1;\x0a    margin-top: 0px;\x0a}\x0a\x0a/* LEFT - RIGHT TABS */\x0aQTabBar::tab:left {\x0a    color: #b1b1b1;\x0a    border: 1px solid #3A3939;\x0a    background-color: QLinearGradient(x1:1, y1:0, x2:0, y2:0,\x0a      stop:1 #302F2F, stop:0 #5A5959);\x0a    padding-left: 3px;\x0a    padding-right: 2px;\x0a    padding-top: 5px;\x0a    padding-bottom: 5px;\x0a    margin-bottom: -1px;\x0a\x0a    border-top-right-radius: 3px;\x0a    border-bottom-right-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:right {\x0a    color: #b1b1b1;\x0a    border: 1px solid #3A3939;\x0a    background-color: QLinearGradient(x1:0, y1:0, x2:1, y2:0,\x0a      stop:1 #302F2F, stop:0 #5A5959);\x0a    padding-left: 3px;\x0a    padding-right: 2px;\x0a    padding-top: 5px;\x0a    padding-bottom: 5px;\x0a    margin-bottom: -1px;\x0a\x0a    border-top-left-radius: 3px;\x0a    border-bottom-left-radius: 3px;\x0a}\x0a\x0aQTabBar::tab:left:!selected\x0a{\x0a    color: #b1b1b1;\x0a    margin-right: 3px;\x0a}\x0a\x0aQTabBar::tab:left:selected\x0a{\x0a    margin-left: 0px;\x0a}\x0a\x0aQTabBar::tab:right:!selected\x0a{\x0a    color: #b1b1b1;\x0a    margin-left: 3px;\x0a}\x0a\x0aQTabBar::tab:right:selected\x0a{\x0a    color: #D1D1D1;\x0a    margin-right: 0px;\x0a}\x0a\x0aQTabBar QToolButton::right-arrow:enabled {\x0a     image: url(:/qss_icons/rc/right_arrow.png);\x0a }\x0a\x0a QTabBar QToolButton::left-arrow:enabled {\x0a     image: url(:/qss_icons/rc/left_arrow.png);\x0a }\x0a\x0aQTabBar QToolButton::right-arrow:disabled {\x0a     image: url(:/qss_icons/rc/right_arrow_disabled.png);\x0a }\x0a\x0a QTabBar QToolButton::left-arrow:disabled {\x0a     image: url(:/qss_icons/rc/left_arrow_disabled.png);\x0a }\x0a\x0a\x0aQDockWidget {\x0a    border: 1px solid lightgray;\x0a    titlebar-close-icon: url(:/qss_icons/rc/close.png);\x0a    titlebar-normal-icon: url(:/qss_icons/rc/undock.png);\x0a}\x0a\x0aQDockWidget::close-button, QDockWidget::float-button {\x0a    border: 1px solid transparent;\x0a    border-radius: 3px;\x0a    background: transparent;\x0a    icon-size: 10px;\x0a}\x0a\x0aQDockWidget::close-button:hover, QDockWidget::float-button:hover {\x0a    background: rgba(255, 255, 255, 10);\x0a}\x0a\x0aQDockWidget::close-button:pressed, QDockWidget::float-button:pressed {\x0a    padding: 1px -1px -1px 1px;\x0a    background: rgba(255, 255, 255, 10);\x0a}\x0a\x0aQTreeView, QListView\x0a{\x0a    border: 1px solid #78879b;\x0a    background-color: #201F1F;\x0a}\x0a\x0aQTreeView:branch:selected, QTreeView:branch:hover\x0a{\x0a    background: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:has-siblings:!adjoins-item {\x0a    border-image: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:has-siblings:adjoins-item {\x0a    border-image: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:!has-children:!has-siblings:adjoins-item {\x0a    border-image: url(:/qss_icons/rc/transparent.png);\x0a}\x0a\x0aQTreeView::branch:has-children:!has-siblings:closed,\x0aQTreeView::branch:closed:has-children:has-siblings {\x0a    image: url(:/qss_icons/rc/branch_closed.png);\x0a}\x0a\x0aQTreeView::branch:open:has-children:!has-siblings,\x0aQTreeView::branch:open:has-children:has-siblings  {\x0a    image: url(:/qss_icons/rc/branch_open.png);\x0a}\x0a\x0aQTreeView::branch:has-children:!has-siblings:closed:hover,\x0aQTreeView::branch:closed:has-children:has-siblings:hover {\x0a    image: url(:/qss_icons/rc/branch_closed-on.png);\x0a    }\x0a\x0aQTreeView::branch:open:has-children:!has-siblings:hover,\x0aQTreeView::branch:open:has-children:has-siblings:hover  {\x0a    image: url(:/qss_icons/rc/branch_open-on.png);\x0a    }\x0a\x0aQListView::item:!selected:hover, QListView::item:!selected:hover, QTreeView::item:!selected:hover  {\x0a    background: rgba(0, 0, 0, 0);\x0a    outline: 0;\x0a    color: #FFFFFF\x0a}\x0a\x0aQListView::item:selected:hover, QListView::item:selected:hover, QTreeView::item:selected:hover  {\x0a    background: #78879b;;\x0a    color: #FFFFFF;\x0a}\x0a\x0aQSlider::groove:horizontal {\x0a    border: 1px solid #3A3939;\x0a    height: 8px;\x0a    background: #201F1F;\x0a    margin: 2px 0;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::handle:horizontal {\x0a    background: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1,\x0a      stop: 0.0 silver, stop: 0.2 #a8a8a8, stop: 1 #727272);\x0a    border: 1px solid #3A3939;\x0a    width: 14px;\x0a    height: 14px;\x0a    margin: -4px 0;\x0a    border-radius: 7px;\x0a}\x0a\x0aQSlider::groove:vertical {\x0a    border: 1px solid #3A3939;\x0a    width: 8px;\x0a    background: #201F1F;\x0a    margin: 0 0px;\x0a    border-radius: 4px;\x0a}\x0a\x0aQSlider::handle:vertical {\x0a    background: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1, stop: 0.0 silver,\x0a      stop: 0.2 #a8a8a8, stop: 1 #727272);\x0a    border: 1px solid #3A3939;\x0a    width: 14px;\x0a    height: 14px;\x0a    margin: 0 -4px;\x0a    border-radius: 7px;\x0a}\x0a\x0aQToolButton {\x0a    background-color: #302F2F;\x0a    border: none;\x0a    border-radius: 3px;\x0a    margin: 3px;\x0a}\x0a\x0aQToolButton[popupMode=\x221\x22]\x0a{\x0a    padding-right: 8px;\x0a}\x0a\x0aQToolButton[popupMode=\x222\x22]\x0a{\x0a    padding-right: 8px;\x0a}\x0a\x0aQToolButton::menu-button {\x0a     border: 2px solid gray;\x0a     border-top-right-radius: 6px;\x0a     border-bottom-right-radius: 6px;\x0a     width: 16px;\x0a }\x0a\x0a QToolButton::menu-arrow {\x0a     image: url(:/qss_icons/rc/down_arrow.png);\x0a     top: 10px; left: 10px; /* shift it a bit */\x0a }\x0a\x0a QToolButton::menu-arrow:open {\x0a     top: 10px; left: 10px; /* shift it a bit */\x0a }\x0a\x0aQToolButton:pressed {\x0a    background-color: #4A4949;\x0a    border: 1px solid silver;\x0a    border-radius: 3px;\x0a}\x0aQToolButton:hover {\x0a    background-color: #4A4949;\x0a    border: 1px solid gray;\x0a    border-radius: 3px;\x0a}\x0a\x0aQPushButton::menu-indicator  {\x0a    subcontrol-origin: padding;\x0a    subcontrol-position: bottom right;\x0a    left: 8px;\x0a}\x0a\x0aQTableView\x0a{\x0a    border: transparent;\x0a    gridline-color: #6c6c6c;\x0a    background-color: #201F1F;\x0a}\x0a\x0a\x0aQTableView, QHeaderView\x0a{\x0a    border-radius: 0px;\x0a}\x0a\x0aQTableView::item:pressed, QListView::item:pressed, QTreeView::item:pressed  {\x0a    background: #78879b;\x0a    color: #FFFFFF;\x0a}\x0a\x0aQTableView::item:selected:active, QTreeView::item:selected:active, QListView::item:selected:active  {\x0a    background: #78879b;\x0a    color: #FFFFFF;\x0a}\x0a\x0a\x0aQHeaderView\x0a{\x0a    border: 1px transparent;\x0a    margin: 0px;\x0a    padding: 0px;\x0a}\x0a\x0aQHeaderView::section  {\x0a    background-color: #3A3939;\x0a    color: silver;\x0a    padding: 4px;\x0a    border: 1px solid #6c6c6c;\x0a    border-radius: 0px;\x0a    text-align: center;\x0a}\x0a\x0aQHeaderView::section::vertical::first, QHeaderView::section::vertical::only-one\x0a{\x0a    border-top: 1px solid #6c6c6c;\x0a}\x0a\x0aQHeaderView::section::vertical\x0a{\x0a    border-top: transparent;\x0a}\x0a\x0aQHeaderView::section::horizontal::first, QHeaderView::section::horizontal::only-one\x0a{\x0a    border-left: 1px solid #6c6c6c;\x0a}\x0a\x0aQHeaderView::section::horizontal\x0a{\x0a    border-left: transparent;\x0a}\x0a\x0a\x0aQHeaderView::section:checked\x0a {\x0a    color: white;\x0a    background-color: #5A5959;\x0a }\x0a\x0a /* style the sort indicator */\x0aQHeaderView::down-arrow {\x0a    image: url(:/qss_icons/rc/down_arrow.png);\x0a}\x0a\x0aQHeaderView::up-arrow {\x0a    image: url(:/qss_icons/rc/up_arrow.png);\x0a}\x0a\x0a\x0aQTableCornerButton::section {\x0a    background-color: #3A3939;\x0a    border: 1px solid #3A3939;\x0a    border-radius: 0px;\x0a}\x0a\x0aQToolBox::tab {\x0a    background-color: QLinearGradient(x1:0, y1:0, x2:0, y2:1,\x0a        stop:1 #302F2F, stop:0 #5A5959);\x0a    padding-left: 3px;\x0a    padding-right: 2px;\x0a    padding-top: 5px;\x0a    padding-bottom: 5px;\x0a    margin-bottom: -1px;\x0a\x0a    border-top-left-radius: 3px;\x0a    border-top-right-radius: 3px;\x0a    color: darkgray;\x0a }\x0a\x0a QToolBox::tab:selected { /* italicize selected tabs */\x0a     font: italic bold;\x0a     color: white;\x0a }\x0a\x00\x00\x00\x96\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x02bKGD\x00\xd3\xb5W\xa0\x5c\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x0c\x0d\x1bu\xfe1\x99\x00\x00\x00'IDAT\x08\xd7e\x8c\xb1\x0d\x00\x00\x08\x83\xe0\xff\xa3up\xb1\xca\xd4\x90Px\x08U!\x14\xb6Tp\xe6H\x8d\x87\xcc\x0f\x0d\xe0\xf0\x08\x024\xe2+\xa7\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x02q\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0e\xc4\x00\x00\x0e\xc4\x01\x95+\x0e\x1b\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x01(tm$I\x00\x00\x01\xf1IDATX\xc3\xcdWAN\x021\x14\xfd\xfd\xb5np!\x89\xb8\x11\x8d\x89[\xef\x80;\xb7\xde\x806p,\xa0\xbd\x86;\xc2\x19\xd8\xb9!\x11\x13#\x0bM\x94I\xb4i\xeb\xc6\xea\xa4a\x86\xb6@\xf0\xef\xc8\xd0y}\xef\xbfy\xed\x07\xd8s\x91\xaa\x07J\xa9W\x00\x00\xe7\xdcR\x08\xd1\xcey\xb9\x94rN\x08i\x00\x00p\xce\x9bQ\x1b\x18\x0c\x06S\xc6\xd8\xa5_\x08\x00`\xad]p\xceOS\xc0\x95R/\x88\xd8\xf2\xbf\x9dsK\xad\xf5\xac\xdf\xef_\x97\xff\x87\xe1\xc2\x10\x1c\x00\x00\x11[R\xcay\x0a\xf328\x00\x00!\xa4\xc1\x18\xbb\xacT`\x15\xf3\xb0\xb4\xd6\xf3^\xafw^\x07>\x1c\x0e\x1f\x19c\x95-\x0b\x95\xc0:\xe6aQJk\x95\x90R\xce)\xa5\xadZ\xd3\x05J\x10o8D<\x8e\x95x\x95'\xc2\x9eG\xbc\xe3\x8ds\xde\xc4\x1cw\x87\x9eX\xd5\xf3\xd8:\xf0}\x01\x80\xe3\x94\x85\x94\xd23\xa5\xd4\x8b\xdfP*\xf0\x0f\xe6\x9f\x09S%\xdc\xa4\xca-\xfcm\x01\xe7\xfc\xd4\x18\xf3\xb4kpc\xccS\xd9?d]\x80\xec\x8aye\x10\xedJ\x89\x90y\xccY\xb05%\xea\xa2\xbc\xf23\xdc\x96\x12U\xcc\xd7*\xb0\x0d%b\x0e1\x84=\x17\xa6\x9ej\x9b$f\xea\x85d\x7f&\xdc\x94y\x8a\x12\xff+\x88\xb6\xcd<F\x89\xffq\x18\xe52\xb7\xd6.\xac\xb5\x8bM\x94@\x7fM\xcaM\xb8\xdc\xc4\xf4\x98\x98+ayV\x10B\xb4s\x94\xf8\xdd\x00\xe7\xbc\xe9o(\xb9\xd9\x9e\xa2\x84sn\xe9\x07\x15,]\xb9g\xeb6\x112\x0fK\x08\xd16\xc6<\x03\x80\xad!\xf0\xa1\xb5\x9eU\xe6\x80\x94\xf2\x1d\x11\x1b\x84\x10R\x02\xfer\xce\xdd\x0a!\xc6\x91\x83\xc9\x0d!\xe4\x1e\x11\x0fC\xe6\xddn\xf7\xa86\x09\xa7\xd3\xe9\x95\xb5vY\x02\xff,\x8a\xe2.\x16\xfcG\x89qQ\x14w\xd6\xda\xcfp I\x1eN'\x93\xc9\xc5h4z\xcf1X\xa7\xd39\x11B<\xd4\x0d\xa7{\xafo\x1a+Z\x88\xa9l\x88.\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x93\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x02bKGD\x00\xd3\xb5W\xa0\x5c\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x0c\x0c+J<0t\x00\x00\x00$IDAT\x08\xd7c`@\x05\xff\xff\xc3XL\xc8\x5c&dY&d\xc5p\x0e##\x9c\xc3\xc8\x88a\x1a\x0a\x00\x00\x9e\x14\x0a\x05+\xca\xe5u\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1f\x0d\xfcR+\x9c\x00\x00\x00$IDAT\x08\xd7c`@\x05s>\xc0XL\xc8\x5c&dY&d\xc5pN\x8a\x00\x9c\x93\x22\x80a\x1a\x0a\x00\x00)\x95\x08\xaf\x88\xac\xba4\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xce\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x07\x00\x00\x00?\x08\x06\x00\x00\x00,{\xd2\x13\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x09/\x07\xd7?\xc4R\x00\x00\x00NIDAT8\xcbc`\x186\x80\x19\xc6\xa8o\x9f\xca\xe0\xe0\xe2\xcd\xf0\xea\xe5s\x867\xaf^000000\xe1\xd39*IH\x92\x05\x89\xfd\x1f\x89\xcd8\x1aB\xa3\x92\x83'i2\x8e\x86\x10\xa9\x92\xf0 \xd3\xd41\x84\x0b^\xbfr\x9ea\x14@\x01\x00\x13M\x0cF\x89*\x0a \x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xb6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x18\x00\x00\x00\x11\x08\x06\x00\x00\x00\xc7xl0\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b,\x0d\x1fC\xaa\xe1\x00\x00\x006IDAT8\xcbc` \x01,Z\xb4\xe8\xff\xa2E\x8b\xfe\x93\xa2\x87\x89\x81\xc6`\xd4\x82\x11`\x01#\xa9\xc9t\xd0\xf9\x80\x85\x1cMqqq\x8c\xa3\xa9h\xd4\x82ad\x01\x001\xb5\x09\xec\x1fK\xb4\x15\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1f \xb9\x8dw\xe9\x00\x00\x00*IDAT\x08\xd7c`\xc0\x06\xe6|```B0\xa1\x1c\x08\x93\x81\x81\x09\xc1d``b`H\x11@\xe2 s\x19\x90\x8d@\x02\x00#\xed\x08\xafd\x9f\x0f\x15\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x1b\x0e\x16M[o\x00\x00\x00*IDAT\x08\xd7c`\xc0\x00\x8c\x0c\x0cs> \x0b\xa4\x08020 \x0b\xa6\x08000B\x98\x10\xc1\x14\x01\x14\x13P\xb5\xa3\x01\x00\xc6\xb9\x07\x90]f\x1f\x83\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xe1\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x0a\x00\x00\x006\x08\x06\x00\x00\x00\xfe\x8a\x08k\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x093\x22zLMH\x00\x00\x00aIDATH\xc7c\xfc\xcf@\x1c`b\xa0\x99Bc##\x06c##\x0c6\x1d\xac\x1eU8\xc8\x142\xfeg``hh\x9f\x8a3Y\xaeZ:\x87\xe1\xda\x95\xf3\x8c4\xb2ZK\xc7\x10o\x8e\xb8v\xe5<#\xe3\x7f\xa4\x84\xcb\xc0\xc0\xc0p\xf6\xdc9\x14\xf6h\x80\x8f\x06\xf8h\x80\x8f\x96fC'=\x0er7\x02\x00\x100@\xb35\xa0|I\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1c\x1f$\xc6\x09\x17\x00\x00\x00$IDAT\x08\xd7c`@\x05\xff\xcf\xc3XL\xc8\x5c&dY&d\xc5p\x0e\xa3!\x9c\xc3h\x88a\x1a\x0a\x00\x00m\x84\x09u7\x9e\xd9#\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x15;\xdc;\x0c\x9b\x00\x00\x00*IDAT\x08\xd7c`\xc0\x00\x8c\x0c\x0cs> \x0b\xa4\x08020 \x0b\xa6\x08000B\x98\x10\xc1\x14\x01\x14\x13P\xb5\xa3\x01\x00\xc6\xb9\x07\x90]f\x1f\x83\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xe4\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x006\x00\x00\x00\x0a\x08\x06\x00\x00\x00\xff\xfd\xad\x0b\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\x7f\x00\x87\x00\x95\xe6\xde\xa6\xaf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x09*+\x98\x90\x5c\xf4\x00\x00\x00dIDATH\xc7c\xfc\xcf0<\x01\x0b\xa5\x064\xb4O\x85\x87\xcd\xaa\xa5s\x18\xae]9\xcfH+5\x14y\xcc\xd8\xc8\x88$\x03|\x89\xd0O-5\x84\xc0\xd9s\xe7\xe0l&\x86\x91\x92\x14\x91}MTR\x0cM&\xa8\x9fZjF\x93\xe2hR\x1c\x82I\x91\x91\xd2zLK\xc7\x10\xc5\x08l\xc54\xb5\xd4\xd0\xd5c\x83\x15\x00\x00z0J\x09q\xea-n\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xc3\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00@\x00\x00\x00@\x08\x06\x00\x00\x00\xaaiq\xde\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x0b\x07\x09.7\xffD\xe8\xf0\x00\x00\x00\x1diTXtComment\x00\x00\x00\x00\x00Created with GIMPd.e\x07\x00\x00\x00'IDATx\xda\xed\xc1\x01\x0d\x00\x00\x00\xc2\xa0\xf7Om\x0e7\xa0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80w\x03@@\x00\x01\xafz\x0e\xe8\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa5\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x02\x04m\x98\x1bi\x00\x00\x00)IDAT\x08\xd7c`\xc0\x00\x8c\x0c\x0c\xff\xcf\xa3\x08\x18220 \x0b2\x1a200B\x98\x10AFC\x14\x13P\xb5\xa3\x01\x00\xd6\x10\x07\xd2/H\xdfJ\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\x9cS4\xfc]\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x1b)\xb3G\xee\x04\x00\x00\x00$IDAT\x08\xd7c`@\x05s>\xc0XL\xc8\x5c&dY&d\xc5pN\x8a\x00\x9c\x93\x22\x80a\x1a\x0a\x00\x00)\x95\x08\xaf\x88\xac\xba4\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01\xc8\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0e\xc4\x00\x00\x0e\xc4\x01\x95+\x0e\x1b\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b\x03$O\xed\x0a\xe0\x00\x00\x01HIDATX\xc3\xedWA\x8e\x830\x0c\xb4!\xd0>\x10?\x8e#\xe7 \xbe\xb3?\xd9U\x03\x9b\xd9K*E\x10\x96$\x04\xf5\x82\xcf.cO\xc6c\x97\xe8\xc3\xc1W|Tkm\x98\xb9:\xca\x03\xb0\xa8\x0b\x9b\xab#r~\xab+\x90E\xa4\x05\xb0\xc4\xe4VW\xb5/\x22\x0d\x80\xf9(o\xf3\x04\xe38.9\x80\x00\xac\x88\xb4\xa9\xbfS\x9ep~\x98\xb9\xcdde\x03\xae\xb5\x9e\x99YE?\xc1\x19p\x00&0\x05*\x9a\x01G{\x16x\xd7uuB\xe7v\x8dsF\x84\xa9\x9d[\x00f=\x1d\xcaZK\xd34\xad\x055\xa7\x0a\xea\xa8s\x9f)WhCDT\x0d\xc3\xf0\x05`#\xea\x0c\xe7S\xb1L9\x9f0Dd\xd9\xd3@\xed1`D\xe4Q\xba\xf3\xe2F\x94\xday\x94\x11\x15\x8a\xe0t8\xbfx\x14c`\xc7\xf3\x93\xa6\xe34\x03\x22\xd2x\xaaN\xf5\x852\xcb\xe8\xad\xea\x1cG,\xa6\x81\xd0\xd4\xc4\x1c%\x97\xad\xe3\xd8\xb8\x0b\xb8\x0b\xb8\x0b\xa8J\xffa\xe9\xfb\xbeq&\xf4\x1dX\xf3qF\xc4\xcc*\xf7:v\xeb\x9d\x00D\x19\x91z\x9f\xd4\xcc\x5c\xaf\x18\xa8\xcfP\xcb\xcc\xa1#\x07\xbbT\xc7\x9e\xd1\xb9\x01\xe0%\x22\xcf\x7f\xdf\xda\xbf\xd5\xcab\xc3\x84\xc0\x83b\xd3Z\xbfJ\x17\xb0\x07ND\xf4\x07\xae\xf5\xd5\xa6\x1d\xd1\x22\x08\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x9e\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x15\x0f\xfd\x8f\xf8.\x00\x00\x00\x22IDAT\x08\xd7c`\xc0\x0d\xfe\x9f\x87\xb1\x18\x91\x05\x18\x0d\xe1BH*\x0c\x19\x18\x18\x91\x05\x10*\xd1\x00\x00\xca\xb5\x07\xd2v\xbb\xb2\xc5\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xbb\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00?\x00\x00\x00\x07\x08\x06\x00\x00\x00\xbfv\x95\x1f\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x095+U\xcaRj\x00\x00\x00;IDAT8\xcbc`\x18\x05#\x130\x12\xa3\xa8\xbe}*%v\xfc\xa7\x97;\xd1\xc1\xaa\xa5s\x18\xae_9\x8fS\x9ei4\xe6\x09\x00M\x1d\xc3!\x19\xf3\x0c\x0c\x0cxc~\x14\x8cT\x00\x00id\x0b\x05\xfdkX\xca\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x9f\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x06\x08\x04\x00\x00\x00\xbb\xce|N\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x08\x14\x1f\xf9#\xd9\x0b\x00\x00\x00#IDAT\x08\xd7c`\xc0\x0d\xe6|\x80\xb1\x18\x91\x05R\x04\xe0B\x08\x15)\x02\x0c\x0c\x8c\xc8\x02\x08\x95h\x00\x00\xac\xac\x07\x90Ne4\xac\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xef\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00Q\x00\x00\x00:\x08\x06\x00\x00\x00\xc8\xbc\xb5\xaf\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b*2\xff\x7f Z\x00\x00\x00oIDATx\xda\xed\xd0\xb1\x0d\x000\x08\x03A\xc8\xa0\x0c\xc7\xa2I\xcf\x04(\xba/]Y\x97\xb1\xb4\xee\xbes\xab\xaa\xdc\xf8\xf5\x84 B\x84(\x88\x10!B\x14D\x88\x10!\x0a\x22D\x88\x10\x05\x11\x22D\x88\x82\x08\x11\x22DA\x84\x08Q\x10!B\x84(\x88\x10!B\x14D\x88\x10!\x0a\x22D\x88\x10\x05\x11\x22D\x88\x82\x08\x11\x22DA\x84\x08Q\x10!B\xfc\xaa\x07\x12U\x04tV\x9e\x9eT\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xa6\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x06\x00\x00\x00\x09\x08\x04\x00\x00\x00\xbb\x93\x95\x16\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x02bKGD\x00\xff\x87\x8f\xcc\xbf\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x14\x1d\x00\xb0\xd55\xa3\x00\x00\x00*IDAT\x08\xd7c`\xc0\x06\xfe\x9fg``B0\xa1\x1c\x08\x93\x81\x81\x09\xc1d``b``4D\xe2 s\x19\x90\x8d@\x02\x00d@\x09u\x86\xb3\xad\x9c\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\xe0\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00Q\x00\x00\x00:\x08\x06\x00\x00\x00\xc8\xbc\xb5\xaf\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x06bKGD\x00\xff\x00\xff\x00\xff\xa0\xbd\xa7\x93\x00\x00\x00\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\x9c\x18\x00\x00\x00\x07tIME\x07\xdc\x08\x17\x0b)\x1c\x08\x84~V\x00\x00\x00`IDATx\xda\xed\xd9\xb1\x0d\x00 \x08\x00AqP\x86cQ\xed\x8d\x85%\x89w\xa5\x15\xf9HE\x8c\xa6\xaaj\x9do\x99\x19\x1dg\x9d\x03\x11E\x14\x11\x11E\x14QDD\x14QD\x11\x11QD\x11EDD\x11E\x14\x11\x11E\x14\xf1[\xd1u\xb0\xdb\xdd\xd9O\xb4\xce\x88(\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\xcf6\xcei\x07\x1e\xe99U@\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x00\x81\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x10\x00\x00\x00\x10\x01\x03\x00\x00\x00%=m\x22\x00\x00\x00\x06PLTE\x00\x00\x00\xae\xae\xaewk\xd6-\x00\x00\x00\x01tRNS\x00@\xe6\xd8f\x00\x00\x00)IDATx^\x05\xc0\xb1\x0d\x00 \x08\x04\xc0\xc3X\xd8\xfe\x0a\xcc\xc2p\x8cm(\x0e\x97Gh\x86Uq\xda\x1do%\xba\xcd\xd8\xfd5\x0a\x04\x1b\xd6\xd9\x1a\x92\x00\x00\x00\x00IEND\xaeB`\x82\x00\x00\x01W\x89PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\x00\x00\x09\x00\x00\x00\x09\x08\x06\x00\x00\x00\xe0\x91\x06\x10\x00\x00\x00\x09pHYs\x00\x00\x0e\xc4\x00\x00\x0e\xc4\x01\x95+\x0e\x1b\x00\x00\x00 cHRM\x00\x00z%\x00\x00\x80\x83\x00\x00\xf9\xff\x00\x00\x80\xe9\x00\x00u0\x00\x00\xea`\x00\x00:\x98\x00\x00\x17o\x92_\xc5F\x00\x00\x00\xddIDATx\xda\x5c\x8e\xb1N\x84@\x18\x84g\xefL,\xc8\xd9,\x0dXP\x1b\x0b\xc3\xfa$w\xbd\x0d\x85O@\x0b\xbb\xcb;\xd0hAr\xc5\xd2(O\x02\xcf\xb1\x97@a\xd4\xc2\xc4b,\xbcM\xd0I\xfe\xbf\xf82\xff?#H\xc2Z;\x00\x80\xd6\xfa\x80\xb3\xac\xb5\x03I\x18c\x0e[!\xc4\x90\xe7\xf9>I\x92\x9b\xbe\xef\xef\xca\xb2|\xf5\xde\xbf\x04\xe6\x9c\xbb\xbd \xf9\x19\xae\x95R\xfb,\xcb\xbe\xa5\x94\x01\x81\xe4\x9b8\xbf<*\xa5\x1e\xf0O\xe38>7M\xf3(H\x02\x00\xba\xae{\x97R\xee\x82aY\x96\x8f\xa2(\xae\x00`\x03\x00\xc6\x98\xe3\xda\x00\x00q\x1c\xef\xb4\xd6O\x00\xb0\x05\xf0'j\x9egDQ\x04\x00H\xd3\xf4\xde9w\xbd!\xf9\xb5\xeapj\xdb\xf6r\x9a\xa6\xd3\xaa\xf8\xef\xaa\xeb\xdaWU\xe5I\x22\xcc\x9a\xfd\x0c\x00$\xabn\xfa\x96!\xfc\xb8\x00\x00\x00\x00IEND\xaeB`\x82"
qt_resource_name = b"\x00\x09\x09_\x97\x13\x00q\x00s\x00s\x00_\x00i\x00c\x00o\x00n\x00s\x00\x0a\x09$M%\x00q\x00d\x00a\x00r\x00k\x00s\x00t\x00y\x00l\x00e\x00\x09\x00(\xad#\x00s\x00t\x00y\x00l\x00e\x00.\x00q\x00s\x00s\x00\x02\x00\x00\x07\x83\x00r\x00c\x00\x12\x07\x8f\x9d'\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00o\x00p\x00e\x00n\x00-\x00o\x00n\x00.\x00p\x00n\x00g\x00\x09\x06\x98\x83'\x00c\x00l\x00o\x00s\x00e\x00.\x00p\x00n\x00g\x00\x14\x06^,\x07\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00c\x00l\x00o\x00s\x00e\x00d\x00-\x00o\x00n\x00.\x00p\x00n\x00g\x00\x18\x03\x8e\xdeg\x00r\x00i\x00g\x00h\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x11\x08\x8cj\xa7\x00H\x00s\x00e\x00p\x00a\x00r\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x1a\x01!\xebG\x00s\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00b\x00r\x00a\x00n\x00c\x00h\x00-\x00m\x00o\x00r\x00e\x00.\x00p\x00n\x00g\x00\x17\x0ce\xce\x07\x00l\x00e\x00f\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x0f\x06S%\xa7\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00o\x00p\x00e\x00n\x00.\x00p\x00n\x00g\x00\x10\x01\x00\xca\xa7\x00H\x00m\x00o\x00v\x00e\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x0f\x02\x9f\x05\x87\x00r\x00i\x00g\x00h\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x17\x0c\xabQ\x07\x00d\x00o\x00w\x00n\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x10\x01\x07J\xa7\x00V\x00m\x00o\x00v\x00e\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x0f\x0c\xe2hg\x00t\x00r\x00a\x00n\x00s\x00p\x00a\x00r\x00e\x00n\x00t\x00.\x00p\x00n\x00g\x00\x0e\x04\xa2\xfc\xa7\x00d\x00o\x00w\x00n\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x11\x0b\xda0\xa7\x00b\x00r\x00a\x00n\x00c\x00h\x00_\x00c\x00l\x00o\x00s\x00e\x00d\x00.\x00p\x00n\x00g\x00\x0a\x05\x95\xde'\x00u\x00n\x00d\x00o\x00c\x00k\x00.\x00p\x00n\x00g\x00\x0c\x06\xe6\xe6g\x00u\x00p\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x11\x08\xc4j\xa7\x00V\x00s\x00e\x00p\x00a\x00r\x00t\x00o\x00o\x00l\x00b\x00a\x00r\x00.\x00p\x00n\x00g\x00\x15\x0f\xf3\xc0\x07\x00u\x00p\x00_\x00a\x00r\x00r\x00o\x00w\x00_\x00d\x00i\x00s\x00a\x00b\x00l\x00e\x00d\x00.\x00p\x00n\x00g\x00\x14\x0b\xc5\xd7\xc7\x00s\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00v\x00l\x00i\x00n\x00e\x00.\x00p\x00n\x00g\x00\x0e\x0e\xde\xfa\xc7\x00l\x00e\x00f\x00t\x00_\x00a\x00r\x00r\x00o\x00w\x00.\x00p\x00n\x00g\x00\x19\x08>\xcc\x07\x00s\x00t\x00y\x00l\x00e\x00s\x00h\x00e\x00e\x00t\x00-\x00b\x00r\x00a\x00n\x00c\x00h\x00-\x00e\x00n\x00d\x00.\x00p\x00n\x00g\x00\x0c\x06A@\x87\x00s\x00i\x00z\x00e\x00g\x00r\x00i\x00p\x00.\x00p\x00n\x00g\x00\x0c\x04V#g\x00c\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00.\x00p\x00n\x00g"
qt_resource_struct = b"\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x18\x00\x02\x00\x00\x00\x01\x00\x00\x00\x1c\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00J\x00\x02\x00\x00\x00\x18\x00\x00\x00\x04\x00\x00\x01\xb4\x00\x00\x00\x00\x00\x01\x00\x00Y]\x00\x00\x022\x00\x00\x00\x00\x00\x01\x00\x00[\x90\x00\x00\x01\x22\x00\x00\x00\x00\x00\x01\x00\x00WO\x00\x00\x01\xda\x00\x00\x00\x00\x00\x01\x00\x00ZB\x00\x00\x00\xc4\x00\x00\x00\x00\x00\x01\x00\x00U\xd9\x00\x00\x03\xfc\x00\x00\x00\x00\x00\x01\x00\x00eb\x00\x00\x02|\x00\x00\x00\x00\x00\x01\x00\x00]?\x00\x00\x02\xc6\x00\x00\x00\x00\x00\x01\x00\x00^\x8c\x00\x00\x03\xde\x00\x00\x00\x00\x00\x01\x00\x00d\xdd\x00\x00\x01\x90\x00\x00\x00\x00\x00\x01\x00\x00X\xb3\x00\x00\x00\x96\x00\x00\x00\x00\x00\x01\x00\x00UB\x00\x00\x00~\x00\x00\x00\x00\x00\x01\x00\x00R\xcd\x00\x00\x02\xe0\x00\x00\x00\x00\x00\x01\x00\x00`X\x00\x00\x00T\x00\x00\x00\x00\x00\x01\x00\x00R3\x00\x00\x03\xa6\x00\x00\x00\x00\x00\x01\x00\x00c\xf9\x00\x00\x00\xfa\x00\x00\x00\x00\x00\x01\x00\x00V}\x00\x00\x02\xfe\x00\x00\x00\x00\x00\x01\x00\x00`\xfa\x00\x00\x03V\x00\x00\x00\x00\x00\x01\x00\x00b\x5c\x00\x00\x02\x9e\x00\x00\x00\x00\x00\x01\x00\x00]\xe8\x00\x00\x01\x5c\x00\x00\x00\x00\x00\x01\x00\x00X\x09\x00\x00\x01\xfe\x00\x00\x00\x00\x00\x01\x00\x00Z\xe6\x00\x00\x02X\x00\x00\x00\x00\x00\x01\x00\x00\x5cx\x00\x00\x03\x84\x00\x00\x00\x00\x00\x01\x00\x00cO\x00\x00\x03&\x00\x00\x00\x00\x00\x01\x00\x00a\xb9\x00\x00\x002\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00"
def qInitResources():
    QtCore.qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
